@@ -242,7 +242,8 @@ findOverlaps(gr, grl, select="first")
 findOverlaps(grl, gr, select="first")
 
 ## ----subjectx_declaration-----------------------------------------------------
-txdb <- TxDb.Hsapiens.UCSC.hg19.knownGene::TxDb.Hsapiens.UCSC.hg19.knownGene
+library(TxDb.Hsapiens.UCSC.hg38.knownGene)
+txdb <- TxDb.Hsapiens.UCSC.hg38.knownGene
 broads <- GenomicFeatures::genes(txdb)
 x <- GRanges(
     seqnames = Rle(c("chr1", "chr2", "chr1", "chr3"), c(1, 3, 2, 4)),
